@@ -29,7 +29,7 @@ class Client(AClient):
         headers = {}
         r: Any = requests.post(
             f"{self.host}/prepare-alastria-id-encode-abi",
-            json=body.get_dict(),
+            json=json.loads(body.json()),
             headers=headers,
         )
         return GenericStrResponse(**r.json())
@@ -39,7 +39,7 @@ class Client(AClient):
         headers = {}
         r: Any = requests.post(
             f"{self.host}/create-alastria-identity",
-            json=body.get_dict(),
+            json=json.loads(body.json()),
             headers=headers,
         )
         return GenericStrResponse(**r.json())
@@ -48,7 +48,7 @@ class Client(AClient):
         headers = {}
         r: Any = requests.post(
             f"{self.host}/identity-keys/{address}",
-            json=body.get_dict(),
+            json=json.loads(body.json()),
             headers=headers,
         )
         return GenericStrResponse(**r.json())
@@ -58,7 +58,7 @@ class Client(AClient):
         headers = {}
         r: Any = requests.post(
             f"{self.host}/signature",
-            json=body.get_dict(),
+            json=json.loads(body.json()),
             headers=headers,
         )
         return GenericStrResponse(**r.json())
@@ -67,7 +67,7 @@ class Client(AClient):
         headers = {}
         r: Any = requests.post(
             f"{self.host}/delegate-call",
-            json=body.get_dict(),
+            json=json.loads(body.json()),
             headers=headers,
         )
         return GenericDictResponse(**r.json())
@@ -77,7 +77,7 @@ class Client(AClient):
         headers = {}
         r: Any = requests.post(
             f"{self.host}/add-key",
-            json=body.get_dict(),
+            json=json.loads(body.json()),
             headers=headers,
         )
         return GenericStrResponse(**r.json())
@@ -87,7 +87,7 @@ class Client(AClient):
         headers = {}
         r: Any = requests.post(
             f"{self.host}/addIdentity-issuer",
-            json=body.get_dict(),
+            json=json.loads(body.json()),
             headers=headers,
         )
         return GenericStrResponse(**r.json())
@@ -98,7 +98,7 @@ class Client(AClient):
         headers = {}
         r: Any = requests.post(
             f"{self.host}/add-issuer-credential",
-            json=body.get_dict(),
+            json=json.loads(body.json()),
             headers=headers,
         )
         return GenericStrResponse(**r.json())
@@ -108,7 +108,7 @@ class Client(AClient):
         headers = {}
         r: Any = requests.post(
             f"{self.host}/run-raw-transaction",
-            json=body.get_dict(),
+            json=json.loads(body.json()),
             headers=headers,
         )
         return GenericStrResponse(**r.json())
\ No newline at end of file
